@@ -482,6 +482,8 @@ func (r *parallelRunner) runProjectConfig(ctx *config.ProjectContext) (*projectO
 		return nil, err
 	}
 
+	_ = r.uploadCloudResourceIDs(projects)
+
 	r.buildResources(projects)
 
 	spinnerOpts := ui.SpinnerOptions{
@@ -533,7 +535,9 @@ func (r *parallelRunner) runProjectConfig(ctx *config.ProjectContext) (*projectO
 
 	spinner.Success()
 
-	r.populateActualCosts(projects)
+	if r.runCtx.Config.UsageActualCosts {
+		r.populateActualCosts(projects)
+	}
 
 	out.projects = projects
 
@@ -544,6 +548,44 @@ func (r *parallelRunner) runProjectConfig(ctx *config.ProjectContext) (*projectO
 	return out, nil
 }
 
+func (r *parallelRunner) uploadCloudResourceIDs(projects []*schema.Project) error {
+	if r.runCtx.Config.UsageAPIEndpoint == "" || !r.hasCloudResourceIDToUpload(projects) {
+		return nil
+	}
+
+	r.runCtx.SetContextValue("uploadedResourceIds", true)
+
+	spinnerOpts := ui.SpinnerOptions{
+		EnableLogging: r.runCtx.Config.IsLogging(),
+		NoColor:       r.runCtx.Config.NoColor,
+		Indent:        "  ",
+	}
+	spinner := ui.NewSpinner("Sending resource IDs to Infracost Cloud for usage estimates", spinnerOpts)
+	defer spinner.Fail()
+
+	for _, project := range projects {
+		if err := prices.UploadCloudResourceIDs(r.runCtx, project); err != nil {
+			logging.Logger.WithError(err).Debugf("failed to upload resource IDs for project %s", project.Name)
+			return err
+		}
+	}
+
+	spinner.Success()
+	return nil
+}
+
+func (r *parallelRunner) hasCloudResourceIDToUpload(projects []*schema.Project) bool {
+	for _, project := range projects {
+		for _, partial := range project.AllPartialResources() {
+			if len(partial.CloudResourceIDs) > 0 {
+				return true
+			}
+		}
+	}
+
+	return false
+}
+
 func (r *parallelRunner) buildResources(projects []*schema.Project) {
 	var projectPtrToUsageMap map[*schema.Project]map[string]*schema.UsageData
 	if r.runCtx.Config.UsageAPIEndpoint != "" {
@@ -600,7 +642,7 @@ func (r *parallelRunner) fetchProjectUsage(projects []*schema.Project) map[*sche
 			logging.Logger.WithError(err).Debugf("failed to retrieve usage data for project %s", project.Name)
 			return nil
 		}
-
+		r.runCtx.SetContextValue("fetchedUsageData", true)
 		projectPtrToUsageMap[project] = usageMap
 	}
 
