@@ -693,3 +693,124 @@ func newDiscardLogger() *logrus.Entry {
 	l.SetOutput(io.Discard)
 	return l.WithFields(logrus.Fields{})
 }
+
+func Test_NestedForEach(t *testing.T) {
+	path := createTestFile("test.tf", `
+
+locals {
+  az = {
+    a = {
+      az = "us-east-1a"
+      bz = "w"
+    }
+    b = {
+      az = "us-east-1b"
+      bz = "z"
+    }
+  }
+}
+
+resource "test_resource" "test" {
+  for_each = local.az
+  availability_zone       = each.value.az
+  another_attr = "attr-${each.value.bz}"
+}
+
+resource "test_resource" "static" {
+  availability_zone       = "az-static"
+  another_attr = "attr-static"
+}
+
+resource "test_resource_two" "test" {
+  for_each        = test_resource.test 
+  inherited_id    = each.value.id
+  inherited_attr  = each.value.another_attr
+}
+`)
+
+	parsers, err := LoadParsers(filepath.Dir(path), []string{}, newDiscardLogger(), OptionStopOnHCLError())
+	require.NoError(t, err)
+	module, err := parsers[0].ParseDirectory()
+	require.NoError(t, err)
+
+	blocks := module.Blocks
+	resources := blocks.OfType("resource")
+	labels := make([]string, len(resources))
+	for i, resource := range resources {
+		labels[i] = resource.Label()
+	}
+	assert.ElementsMatch(t, []string{
+		`test_resource.test["a"]`,
+		`test_resource.test["b"]`,
+		`test_resource.static`,
+		`test_resource_two.test["a"]`,
+		`test_resource_two.test["b"]`,
+	}, labels)
+}
+
+func Test_ModuleForEaches(t *testing.T) {
+
+	path := createTestFileWithModule(`
+locals {
+  az = {
+    a = {
+      az = "us-east-1a"
+      bz = "w"
+    }
+    b = {
+      az = "us-east-1b"
+      bz = "z"
+    }
+  }
+}
+
+module "test" {
+    for_each = local.az
+	source = "../."
+	input = "ok"
+}
+
+resource "test_two" "test" {
+  for_each        = module.test 
+  inherited_id    = each.value.id
+  inherited_attr  = each.value.another_attr
+}
+`,
+		`
+variable "input" {
+	default = "?"
+}
+
+output "mod_result" {
+	value = var.input
+}
+`,
+		"",
+	)
+
+	parsers, err := LoadParsers(path, []string{}, newDiscardLogger(), OptionStopOnHCLError())
+	require.NoError(t, err)
+	module, err := parsers[0].ParseDirectory()
+	require.NoError(t, err)
+
+	blocks := module.Blocks
+	resources := blocks.OfType("resource")
+	labels := make([]string, len(resources))
+	for i, resource := range resources {
+		labels[i] = resource.Label()
+	}
+	assert.ElementsMatch(t, []string{
+		`test_two.test["a"]`,
+		`test_two.test["b"]`,
+	}, labels)
+
+	modules := blocks.OfType("module")
+	modLabels := make([]string, len(modules))
+	for i, module := range modules {
+		modLabels[i] = "module." + module.Label()
+	}
+	assert.ElementsMatch(t, []string{
+		`module.test["a"]`,
+		`module.test["b"]`,
+	}, modLabels)
+}
