@@ -5,10 +5,12 @@ import (
 	"fmt"
 	"os"
 	"path/filepath"
+	"regexp"
 	"sort"
 	"strings"
 	"time"
 
+	"github.com/Rhymond/go-money"
 	"github.com/mitchellh/go-homedir"
 	"github.com/pkg/errors"
 	"github.com/shopspring/decimal"
@@ -16,6 +18,7 @@ import (
 
 	"github.com/infracost/infracost/internal/clierror"
 	"github.com/infracost/infracost/internal/schema"
+	log "github.com/sirupsen/logrus"
 )
 
 var (
@@ -285,6 +288,10 @@ func FormatOutput(format string, r Root, opts Options) ([]byte, error) {
 	var b []byte
 	var err error
 
+	if opts.CurrencyFormat != "" {
+		addCurrencyFormat(opts.CurrencyFormat)
+	}
+
 	switch format {
 	case "json":
 		b, err = ToJSON(r, opts)
@@ -312,3 +319,31 @@ func FormatOutput(format string, r Root, opts Options) ([]byte, error) {
 
 	return b, nil
 }
+
+func addCurrencyFormat(currencyFormat string) {
+	rgx := regexp.MustCompile(`^(.{3}): (.*)1(,|\.)234(,|\.)?([0-9]*)?(.*)$`)
+	m := rgx.FindStringSubmatch(currencyFormat)
+
+	if len(m) == 0 {
+		log.Warningf("Invalid currency format: %s", currencyFormat)
+		return
+	}
+
+	currency := m[1]
+
+	graphemeWithSpace := m[2]
+	grapheme := strings.TrimSpace(graphemeWithSpace)
+	template := "$" + strings.Repeat(" ", len(graphemeWithSpace)-len(grapheme)) + "1"
+
+	if graphemeWithSpace == "" {
+		graphemeWithSpace = m[6]
+		grapheme = strings.TrimSpace(graphemeWithSpace)
+		template = "1" + strings.Repeat(" ", len(graphemeWithSpace)-len(grapheme)) + "$"
+	}
+
+	thousand := m[3]
+	decimal := m[4]
+	fraction := len(m[5])
+
+	money.AddCurrency(currency, grapheme, template, decimal, thousand, fraction)
+}
