@@ -1,6 +1,7 @@
 package output
 
 import (
+	"github.com/Rhymond/go-money"
 	"testing"
 
 	"github.com/google/go-cmp/cmp"
@@ -103,7 +104,10 @@ func TestCurrencyFormatCost(t *testing.T) {
 
 	for name, tc := range tests {
 		t.Run(name, func(t *testing.T) {
+			reset := resetCurrencyFormatFunc(tc.format)
 			addCurrencyFormat(tc.format)
+			defer reset()
+
 			var val *decimal.Decimal
 			if tc.val != "" {
 				parsed, err := decimal.NewFromString(tc.val)
@@ -122,6 +126,14 @@ func TestCurrencyFormatCost(t *testing.T) {
 	}
 }
 
+func resetCurrencyFormatFunc(format string) func() {
+	code := format[0:3]
+	currency := money.GetCurrency(code)
+	return func() {
+		money.AddCurrency(currency.Code, currency.Grapheme, currency.Template, currency.Decimal, currency.Thousand, currency.Fraction)
+	}
+}
+
 func TestFormatPrice(t *testing.T) {
 	tests := map[string]struct {
 		currency string
