@@ -14,3 +14,12 @@ func TestAzureRMLoadBalancerOutboundRuleGoldenFile(t *testing.T) {
 
 	tftest.GoldenFileResourceTests(t, "lb_outbound_rule_test")
 }
+
+func TestAzureRMLoadBalancerOutboundRuleV2GoldenFile(t *testing.T) {
+	t.Parallel()
+	if testing.Short() {
+		t.Skip("skipping test in short mode")
+	}
+
+	tftest.GoldenFileResourceTests(t, "lb_outbound_rule_v2_test")
+}
