@@ -91,6 +91,15 @@ func NewProject(name string, metadata *ProjectMetadata) *Project {
 	}
 }
 
+// NameWithWorkspace returns the proect Name appended with the paranenthized workspace name
+// from Metadata if one exists.
+func (p *Project) NameWithWorkspace() string {
+	if p.Metadata.WorkspaceLabel() == "" {
+		return p.Name
+	}
+	return fmt.Sprintf("%s (%s)", p.Name, p.Metadata.WorkspaceLabel())
+}
+
 // AllResources returns a pointer list of all resources of the state.
 func (p *Project) AllResources() []*Resource {
 	var resources []*Resource
@@ -99,6 +108,14 @@ func (p *Project) AllResources() []*Resource {
 	return resources
 }
 
+// AllPartialResources returns a pointer list of the current and past partial resources
+func (p *Project) AllPartialResources() []*PartialResource {
+	var resources []*PartialResource
+	resources = append(resources, p.PartialPastResources...)
+	resources = append(resources, p.PartialResources...)
+	return resources
+}
+
 // CalculateDiff calculates the diff of past and current resources
 func (p *Project) CalculateDiff() {
 	if p.HasDiff {
